# Harbour project
Launch AWS containers easily.
### Commands to use it
```
pip install --upgrade harbour
harbour configure
```
***In order to get the configuration for harbour, access it's secret on LastPass***

## Harbour Architecture

![Image of Yaktocat](https://github.com/ebanx/harbour/blob/master/harbour_diagram.png)
